@@ -8,7 +8,9 @@ use Moose;
 
 extends 'Business::AU::Ledger::View::Base';
 
-our $VERSION = '0.84';
+use namespace::autoclean;
+
+our $VERSION = '0.85';
 
 # -----------------------------------------------
 
@@ -139,6 +141,6 @@ sub update
 
 # --------------------------------------------------
 
-no Moose;
+__PACKAGE__ -> meta -> make_immutable;
 
 1;
