@@ -13,7 +13,9 @@ extends 'Business::AU::Ledger::View::Base';
 has field_width => (is => 'rw', isa => 'HashRef');
 has row_count   => (is => 'rw', isa => 'Int');
 
-our $VERSION = '0.84';
+use namespace::autoclean;
+
+our $VERSION = '0.85';
 
 # -----------------------------------------------
 
@@ -368,6 +370,6 @@ sub total
 
 # --------------------------------------------------
 
-no Moose;
+__PACKAGE__ -> meta -> make_immutable;
 
 1;
